@@ -18,10 +18,23 @@ from .db_sound_definitions import (
     SOUND_DEFINITIONS_BUILD_SCRIPT, load_sound_definitions)
 from .db_sound import (
     SOUND_BUILD_SCRIPT, load_sounds)
+from .db_rp_item import (
+    RP_ITEM_BUILD_SCRIPT, load_rp_items)
 from .db_behavior_pack import (
     BEHAVIOR_PACK_BUILD_SCRIPT, load_behavior_pack)
 from .db_entity import (
     ENTITY_BUILD_SCRIPT, load_entities)
+from .db_loot_table import (
+    LOOT_TABLE_BUILD_SCRIPT, load_loot_tables)
+from .db_trade_table import (
+    TRADE_TABLE_BUILD_SCRIPT, load_trade_tables)
+from .db_bp_animation import (
+    BP_ANIMATION_BUILD_SCRIPT, load_bp_animations)
+from .db_bp_animation_controller import (
+    BP_ANIMATION_CONTROLLER_BUILD_SCRIPT, load_bp_animation_controllers)
+from .db_bp_item import (
+    BP_ITEM_BUILD_SCRIPT, load_bp_items)
+
 
 SCRIPT = '''
 PRAGMA foreign_keys = ON;
@@ -61,9 +74,15 @@ def create_db(db_path: str = ":memory:") -> Connection:
     db.executescript(ATTACHABLE_BUILD_SCRIPT)
     db.executescript(SOUND_DEFINITIONS_BUILD_SCRIPT)
     db.executescript(SOUND_BUILD_SCRIPT)
+    db.executescript(RP_ITEM_BUILD_SCRIPT)
 
     db.executescript(BEHAVIOR_PACK_BUILD_SCRIPT)
     db.executescript(ENTITY_BUILD_SCRIPT)
+    db.executescript(LOOT_TABLE_BUILD_SCRIPT)
+    db.executescript(TRADE_TABLE_BUILD_SCRIPT)
+    db.executescript(BP_ANIMATION_BUILD_SCRIPT)
+    db.executescript(BP_ANIMATION_CONTROLLER_BUILD_SCRIPT)
+    db.executescript(BP_ITEM_BUILD_SCRIPT)
     return db
 
 def open_db(db_path: str) -> Connection:
@@ -91,6 +110,7 @@ DbRpItems = Literal[
     "attachables",
     "sound_definitions",
     "sounds",
+    "rp_items"
 ]
 '''
 Possible values of :code:`include and :code:`exclude` arguments of
@@ -111,6 +131,7 @@ def load_rp(
             "attachables",
             "sound_definitions",
             "sounds",
+            "rp_items"
         ),
         exclude: Iterable[DbRpItems] = tuple()
     ) -> None:
@@ -169,17 +190,27 @@ def load_rp(
             "sounds" in include and
             "sounds"  not in exclude):
         load_sounds(db, rp_pk)
+    if (
+            "rp_items" in include and
+            "rp_items" not in exclude):
+        load_rp_items(db, rp_pk)
     db.commit()
 
 DbBpItems = Literal[
     "entities",
+    "loot_tables",
+    "trade_tables",
+    "bp_animations"
+    "bp_animation_controllers",
+    "bp_items"
 ]
 
 def load_bp(
         db: Connection,
         bp_path: Path,
         include: Iterable[DbBpItems] = (
-            "entities",
+            "entities", "loot_tables", "trade_tables", "bp_animations",
+            "bp_animation_controllers", "bp_items"
         ),
         exclude: Iterable[DbRpItems] = tuple()) -> None:
     '''
@@ -198,8 +229,27 @@ def load_bp(
     '''
     bp_pk = load_behavior_pack(db, bp_path)
     if (
-        "entities" in include and
-        "entities" not in exclude
-    ):
+            "entities" in include and
+            "entities" not in exclude):
         load_entities(db, bp_pk)
+    if (
+            "loot_tables" in include and
+            "loot_tables" not in exclude):
+        load_loot_tables(db, bp_pk)
+    if (
+            "trade_tables" in include and
+            "trade_tables" not in exclude):
+        load_trade_tables(db, bp_pk)
+    if (
+            "bp_animations" in include and
+            "bp_animations"  not in exclude):
+        load_bp_animations(db, bp_pk)
+    if (
+            "bp_animation_controllers" in include and
+            "bp_animation_controllers"  not in exclude):
+        load_bp_animation_controllers(db, bp_pk)
+    if (
+            "bp_items" in include and
+            "bp_items"  not in exclude):
+        load_bp_items(db, bp_pk)
     db.commit()
